*****************************************
* Do-File for the replication of
* "Wer ist in Deutschland willkommen?
* Eine Vignettenanalyse zur Akzeptanz von 
* Einwanderern", Klner Zeitschrift fr
* Soziologie und Sozialpsychologie (2016)
* Authors: Christian Czymara und 
* Alexander Schmidt-Catran
* 16.03.2016
*****************************************


* OUR DATA SET CAN BE USED FOR SECONDARY DATA ANALYSIS, TEACHING 
* OR ANY OTHER PURPOSE FOR FREE. PLEASE CITE OUR PAPER IF YOU DO SO:

* 		Czymara, Christian and Schmidt-Catran, Alexander W. (2016): Wer ist in Deutschland willkommen? Eine Vignettenanalyse zur 
* 			Akzeptanz von Einwanderern. Klner Zeitschrift fr Soziologie und Sozialpsychologie, 68(2?), pp.??. 



*****************************************
* Notes: This do-file needs two ados. 
* Make sure they are installed:
*ssc install mlt
*ssc install coefplot
*****************************************

version 13.1
set more off
capture log close
log using Czymara_SchmidtCatran_KZfSS.log, replace
use Czymara_SchmidtCatran_KZfSS, clear


****************************
* Data/Variable Manipulation
****************************

* Generate four-fold employment status variable
recode res_employment2  2 3 = 2 4 = 3, gen(res_employment4)
	replace res_employment4 = 4 if res_employment4 == 3 & res_employment3 == 0
	label define res_employment4 1 "Full-time employed" 2 "Part-time employed" 3 "Unemployed" 4 "Not in labor force"
	label values res_employment4 res_employment4
	label variable res_employment4 "Employment status (4 cats)

* Recode Immigrant friends variable
recode res_migr_friends 1 2 = 1 3 = 2 4 = 3, gen(res_migr_friends1)
		label variable res_migr_friends "Migrant friends (3 cats)"
		label define res_migr_friends1 1 "Many/Some" 2 "Few" 3 "None"
		label values res_migr_friends1 res_migr_friends1

* Generate migration background variable
gen res_migbackgr = .
		replace res_migbackgr = 0 if res_mig1==1 & res_mig2==1 & res_mig3==1
		replace res_migbackgr = 1 if res_mig1==0 | res_mig2==2 | res_mig2==3 | res_mig2==4 | res_mig3==2 | res_mig3==3
		label var res_migbackgr "Migration Background of Respondent"
		label values res_migbackgr ynlbl

* Generate household income variable
gen res_hh_income = res_hh_income_metric
		replace res_hh_income = res_hh_income_metric/(1 + 0.5*res_people_hh_old + 0.3*res_people_hh_young) if res_people_hh == 1
		label var res_hh_income "Household income of respondent (OECD-modified scale)"

* Generate East-Germany dummy
gen res_eastgerman = .
		label var res_eastgerman "Respondent coming from East Germany (w/o Berlin)"
		replace res_eastgerman = 1 if res_state==4 | res_state==8 | res_state==13 | res_state==14 | res_state==16
		replace res_eastgerman = 0 if res_state==1 | res_state==2 | res_state==5 | res_state==6 | ///
								res_state==7 | res_state==9 | res_state==10 | res_state==11 | ///
								res_state==12 | res_state==15
		label values res_eastgerman ynlbl

* Assign open answers of education to categories where possible
replace res_educ = 5 if res_education_other == 1 | res_education_other == 2 ///
						| res_education_other == 6 | res_education_other == 7 | res_education_other == 8 ///
						| res_education_other == 17 | res_education_other == 18 | res_education_other == 19 ///
						| res_education_other == 20 | res_education_other == 21 ///
						| res_education_other == 23 | res_education_other == 24 | res_education_other == 25 ///
						| res_education_other == 26 | res_education_other == 27 | res_education_other == 30 ///
						| res_education_other == 32 | res_education_other == 33
replace res_educ = 7 if res_education_other == 3 | res_education_other == 22
replace res_educ = 8 if res_education_other == 9
replace res_educ = 9 if res_education_other == 10 | res_education_other == 11 ///
				| res_education_other == 12 | res_education_other == 13 | res_education_other == 14 ///
				| res_education_other == 15 | res_education_other == 16 | res_education_other == 28 ///
				| res_education_other == 29 | res_education_other == 31 // "Fachschule" siehe https://de.wikipedia.org/wiki/Fachschule_%28Deutschland%29#Fachschulen_in_der_DDR

* Generate variable with three categories
gen res_educ_cat = .
		replace res_educ_cat = 1 if res_educ == 2 | res_educ ==3
		replace res_educ_cat = 2 if res_educ == 4 | res_educ ==5
		replace res_educ_cat = 3 if res_educ == 6 | res_educ == 7 ///
							| res_educ == 8 | res_educ == 9 ///
							| res_educ == 10
		label var res_educ_cat "Education of Respondent (Categorical)
		label define educcatlbl 1 "Low" 2 "Medium" 3 "High"
		label values res_educ_cat educcatlbl

* Assign open answers of religious denomination to categories where possible
replace res_religion1 = 4 if res_religion1_other == 1
replace res_religion1 = 6 if res_religion1_other == 2 | res_religion1_other == 8 ///
							| res_religion1_other == 13

* Generate religion variable (Christian vs. other vs. none)
gen res_rel_christ_other=.
		replace res_rel_christ_other=1 if res_religion1 ==1 | res_religion1 ==2 | (res_religion1_other >= 3 & res_religion1_other <= 7) ///
					| (res_religion1_other >= 10 & res_religion1_other <= 13) | (res_religion1_other >= 15 & res_religion1_other <= 23) ///
					| (res_religion1_other >= 26 & res_religion1_other <= 31)
		replace res_rel_christ_other=2 if (res_religion1 >= 3 & res_religion1 <= 5) ///
					| res_religion1_other == 9 | res_religion1_other == 14 ///
					| res_religion1_other == 24
		replace res_rel_christ_other=3 if res_religion1 == 6
		label var res_rel_christ_other "Respondent Christian, Other or None"
		label define christlbl 1 "Christian" 2 "Other" 3 "None"
		label values res_rel_christ_other christlbl

* Generate age quartiles
xtile res_age_quart = res_age, nq(4)
label define agequartlbl 1 "Min. (14) to 29 Years" 2 "30 to 44 Years" 3 "45 to 56 Years" 4 "57 to Max. (95)"
label values res_age_quart agequartlbl

* Describe and select sample
bys id_res: gen vig_counter = _N
tab vig_counter
drop vig_counter
inspect id_res
	dis r(N)/14		// respondents-level N before listwise deletion


reg vig_rating_live i.vig_gender i.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion  ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr i.res_rel_christ_other ///
	i.res_migr_friends1 i.res_eastgerman
keep if e(sample)
bys id_res: gen vig_counter = _N
tab vig_counter
drop vig_counter
inspect id_res
	dis r(N)/14		// respondents-level N after listwise deletion

**************
* Descriptives
**************

* Describe factor correlations (Vignette levels) - Tabelle 1
tab vig_reason, gen(vig_reason_d)
tab vig_religion, gen(vig_rel_d)
tab vig_origin, gen(vig_origin_d)
corr vig_gender vig_reason_d1 vig_reason_d2 vig_reason_d3 vig_rel_d1 vig_rel_d2 vig_rel_d3 ///
vig_origin_d1 vig_origin_d2 vig_origin_d3 vig_qualific vig_language
	

* Describe respondent level variables - Tabelle A1
tab res_employment4, gen(res_empl_) 
tab res_educ_cat, gen(res_educ_)
tab res_rel_christ_other, gen(res_relig_)
tab res_migr_friends, gen(res_migfr_)
bys id_res: gen help = _n
sum res_gender res_age res_empl_? res_educ_? res_relig_? res_migbackgr res_eastgerman res_migfr_? if help == 1
	
* Describe correlation of respondent level characteristics - Tabelle A2
corr res_gender res_age res_empl_? res_educ_? res_relig_? res_migbackgr res_eastgerman res_migfr_? if help == 1

drop res_empl_? res_educ_? res_relig_? res_migfr_? help

* Describe distribution of dependent variables - Abbildung 2
sum vig_rating_live
	local a = r(mean)
hist vig_rating_live, discrete percent scheme(s1mono) xlabel(1(1)7) xtitle("Aufenthaltserlaubnis") ytitle("Anteil in %") name(hist1, replace) xline(`a')
sum vig_rating_work
	local a = r(mean)
hist vig_rating_work, discrete percent scheme(s1mono) xlabel(1(1)7) xtitle("Arbeitserlaubnis") ytitle("Anteil in %") name(hist2, replace) xline(`a')
sum vig_rating_social_ben
	local a = r(mean)
hist vig_rating_social_ben, discrete percent scheme(s1mono) xlabel(1(1)7) xtitle("Sozialhilfe") ytitle("Anteil in %") name(hist3, replace) xline(`a')

graph combine hist1 hist2 hist3, col(1) name(hist_c, replace) scheme(s1mono) ycommon
graph display hist_c, ysize(10)

	
***************
* Analysis	
***************

* Empty Models
xtmixed vig_rating_live || id_res: , mle var 
	est store m0_l
	xtmrho
xtmixed vig_rating_work || id_res: , mle var 
	est store m0_w
	xtmrho
xtmixed vig_rating_social_ben || id_res: , mle var 
	est store m0_b
	xtmrho
	
* Adding vignette characteristics
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		|| id_res: , mle var baselevel
	mltrsq
	est store m1_l
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		|| id_res: , mle var baselevel
	mltrsq
	est store m1_w
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion || id_res: , mle var baselevel
	mltrsq
	est store m1_b
	
* Adding respondents' socio-economic characteristics
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m2_l
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m2_w
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m2_b


* Adding Interactions with cultural variables 
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#i.vig_religion i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m3_l
	lrtest m2_l		// significant improvement in model fit
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#i.vig_religion i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m3_w
	lrtest m2_w		// significant improvement in model fit
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other  		///
	ib3.res_rel_christ_other#i.vig_religion i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m3_b
	lrtest m2_b		// no significant improvement 	
	
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#ib1.vig_origin		i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m4_l
	lrtest m2_l		// not significant
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#ib1.vig_origin	i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m4_w	
	lrtest m2_w		// not significant
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other  		///
	ib3.res_rel_christ_other#ib1.vig_origin	i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m4_b
	lrtest m2_b		// not significant


* Adding Interactions with economic variables
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	i.res_educ_cat#i.vig_qualific i.res_eastgerman	|| id_res: , mle var baselevel
	mltrsq
	est store m5_l
	lrtest m2_l		// not significant
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	i.res_educ_cat#i.vig_qualific	i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m5_w	
	lrtest m2_w  	// significant 
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other  		///
	i.res_educ_cat#i.vig_qualific i.res_eastgerman	|| id_res: , mle var baselevel
	mltrsq
	est store m5_b
	lrtest m2_b		// not significant
	
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	i.res_employment4#i.vig_qualific i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m6_l
	lrtest m2_l		// significant
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	i.res_employment4#i.vig_qualific i.res_eastgerman	|| id_res: , mle var baselevel
	mltrsq
	est store m6_w	
	lrtest m2_w		// significant
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other  		///
	i.res_employment4#i.vig_qualific i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m6_b
	lrtest m2_b		// not significant
	
* Add three-way interaction with empployment status and educational level conditioning effect of vignette education
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific i.res_eastgerman								///
	i.res_employment4#i.res_educ_cat#i.vig_qualific || id_res: , mle var baselevel
	mltrsq
	est store m7_l
	lrtest m2_l		// significant
	lrtest m5_l		// not significant
	lrtest m6_l		// not significant
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific i.res_eastgerman								///
	i.res_employment4#i.res_educ_cat#i.vig_qualific || id_res: , mle var baselevel
	mltrsq
	est store m7_w	
	lrtest m2_w		// significant
	lrtest m5_w		// significant
	lrtest m6_w		// not significant
	xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other  		///
	i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific i.res_eastgerman								///
	i.res_employment4#i.res_educ_cat#i.vig_qualific || id_res: , mle var baselevel
	mltrsq
	est store m7_b
	lrtest m2_b		// not significant
	lrtest m5_b		// not significant
	lrtest m6_b		// not significant	
	
* Joining the significant interactions in one model
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#i.vig_religion i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific		///
	i.res_employment4#i.res_educ_cat#i.vig_qualific i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m8_l
	lrtest m2_l		// significant
	lrtest m3_l		// significant
	lrtest m5_l		// significant
	lrtest m7_l		// significant
xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#i.vig_religion i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific		///
	i.res_employment4#i.res_educ_cat#i.vig_qualific	i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m8_w
	lrtest m2_w		// significant
	lrtest m3_w		// significant
	lrtest m5_w		// significant
	lrtest m7_w		// significant
xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion	///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 			///
	ib3.res_rel_christ_other#i.vig_religion i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific			///
	i.res_employment4#i.res_educ_cat#i.vig_qualific	i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m8_b
	lrtest m2_b		// not significant
	lrtest m3_b		// not significant
	lrtest m5_b		// not significant
	lrtest m7_b		// not significant
	
* Adding respondents' contact with immigrants 
xtmixed vig_rating_live i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#i.vig_religion i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific		///
	i.res_employment4#i.res_educ_cat#i.vig_qualific	i.res_migr_friends i.res_eastgerman	|| id_res: , mle var baselevel
	mltrsq
	est store m9_l
	lrtest m8_l		// significant

xtmixed vig_rating_work i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion		///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 		///
	ib3.res_rel_christ_other#i.vig_religion i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific		///
	i.res_employment4#i.res_educ_cat#i.vig_qualific	i.res_migr_friends	i.res_eastgerman || id_res: , mle var baselevel
	mltrsq
	est store m9_w
	lrtest m8_w		// significant

xtmixed vig_rating_social_ben i.vig_gender ib1.vig_origin i.vig_reason i.vig_qualific i.vig_language i.vig_religion	  ///
	i.res_gender i.res_age_quart i.res_employment4 i.res_educ_cat i.res_migbackgr ib3.res_rel_christ_other 			  ///
	ib3.res_rel_christ_other#i.vig_religion i.res_employment4#i.vig_qualific i.res_educ_cat#i.vig_qualific			  ///
	i.res_employment4#i.res_educ_cat#i.vig_qualific	i.res_migr_friends	i.res_eastgerman  || id_res: , mle var baselevel
	mltrsq
	est store m9_b
	lrtest m8_b		// significant

	


* Tables for main text in the paper 
est tab m0_? m1_? m2_?, star varwidth(30) b(%9,3f) baselevels equations(1) stats(aic bic  br_rsq_l2 br_rsq_l1) 	// Tabelle A3
est tab m8_l m8_w m8_b m9_l m9_w m9_b, star varwidth(30) b(%9,3f) baselevels equations(1) stats(aic bic br_rsq_l1 br_rsq_l2) 	// Tabelle A4

* Tables for online appendix
est tab m2_? m3_? m4_?, star varwidth(30) b(%9,3f) baselevels equations(1) stats(aic bic br_rsq_l1 br_rsq_l2) // Tabelle OA1
est tab m2_? m5_? m6_? m7_?, star varwidth(30) b(%9,3f) baselevels equations(1) stats(aic bic br_rsq_l1 br_rsq_l2) // Tabelle OA2

	
* Graphical presentation of results - Abbildung 3
 
 * Vignette characteristics - Abbildung 3a
  coefplot (m2_l, label("Aufenthaltserlaubnis"))  (m2_w, label("Arbeitserlaubnis"))   (m2_b, label("Sozialleistungen")) ///
 , drop(_cons) scheme(s1mono) xline(0) msymbol(circle) aspect(0.95) scale(0.75)  ///
 keep(1.vig_gender 0.vig_origin 2.vig_origin 1.vig_reason 2.vig_reason 1.vig_qualific 1.vig_language 1.vig_religion 2.vig_religion) ///
 coeflabels(1.vig_gender = "   Mann" 0.vig_origin = "   Libanon" 2.vig_origin = "   Kenia" ///
 1.vig_reason = "   Verfolgt" 2.vig_reason = "   Arbeitsplatz"  ///
 1.vig_qualific = "   Hochqualifiziert" 1.vig_language = "   Gut" 1.vig_religion = "   Christ" ///
 2.vig_religion = "   Moslem", labgap(-167) notick) ///
 headings(1.vig_gender = "Geschlecht (Ref. = Frau)" 0.vig_origin = "Herkunftsland (Ref. = Frankreich)" ///
 1.vig_reason = "Motiv (Ref. = besseres Leben)" 1.vig_qualific = "Qualifikation (Ref. = gering)" ///
 1.vig_language = "Deutschkenntnisse (Ref. = kaum)" 1.vig_religion = "Religion (Ref. = keine)" , nogap ) ///
 xtitle(Koeffizient)  graphregion(margin(l=10 r=-40)) yscale(alt)
 
 
 
* Respondents' characteristics - Abbildung 3b
 coefplot (m2_l, label("Aufenthaltserlaubnis"))  (m2_w, label("Arbeitserlaubnis"))   (m2_b, label("Sozialleistungen")) ///
 , drop(_cons) scheme(s1mono) xline(0) msymbol(circle) aspect(0.95) scale(0.75)  ///
 keep(1.res_gender 2.res_age_quart 3.res_age_quart 4.res_age_quart  2.res_employment4 ///
 3.res_employment4  4.res_employment4 2.res_educ_cat 3.res_educ_cat  1.res_migbackgr 1.res_rel_christ_other ///
 2.res_rel_christ_other 1.res_eastgerman) ///
 coeflabels(1.res_gender = "   Mann" 2.res_age_quart = "   30-44 years"  ///
 3.res_age_quart = "   45-56 years" 4.res_age_quart = "   >56 years"  ///
 2.res_employment4 = "   Teilzeit" 3.res_employment4 = "   Arbeitslos" ///
 4.res_employment4 = "   Nicht erwerbstätig" 2.res_educ_cat = "   Mittlere Bildung"  ///
 3.res_educ_cat = "   Hohe Bildung" 1.res_migbackgr = "   Ja" ///
 1.res_rel_christ_other = "   Christ" 2.res_rel_christ_other = "   Andere" ///
 1.res_eastgerman = "   Ostdeutschland", labgap(-167) notick) ///
 headings(1.res_gender = "Geschlecht (Ref. = Frau)" 2.res_age_quart = "Alter (Ref. = < 30 years)" ///
 2.res_employment4 = "Arbeitsmarktstatus (Ref. = Vollzeit)" 2.res_educ_cat = "Bildung (Ref. = geringe)" ///
 1.res_migbackgr = "Migrationshintergrund (Ref. = nein)" 1.res_rel_christ_other = "Religion (Ref. = keine)" ///
 1.res_eastgerman = "Wohnort (Ref. = Westdeutschland)", nogap) ///
 xtitle(Koeffizient)  graphregion(margin(l=10 r=-40)) yscale(alt)

 
  
 
 * Additional statistical tests reported in the text of the paper
 est restore m9_l
 margins ib3.res_rel_christ_other, dydx(i.vig_religion) post baselevels
	est store mar9_l_rel
	test _b[1.vig_religion:1bn.res_rel_christ_other]=_b[2.vig_religion:1bn.res_rel_christ_other]	// christians treat christians and moslems differently
	test  _b[1.vig_religion:2.res_rel_christ_other]= _b[2.vig_religion:2.res_rel_christ_other]		// other religous people do not
	marginsplot, recast(scatter) scheme(s1mono) yline(0)
 est restore m9_w 
 margins ib3.res_rel_christ_other, dydx(i.vig_religion) post
	est store mar9_w_rel
 est restore m9_b
 margins ib3.res_rel_christ_other, dydx(i.vig_religion) post
	est store mar9_b_rel
 
* Plotting interactions among cultural variables - Abbildung 4
 coefplot (mar9_l_rel, label("Aufenthaltserlaubnis")) (mar9_w_rel, label("Arbeitserlaubnis")) (mar9_b_rel, label("Sozialleistungen")) ///
 , scheme(s1mono) msymbol(circle) aspect(1)  scale(.75) xline(0)  ///
keep(1.vig_religion:1.res_rel_christ_other 2.res_rel_christ_other 3.res_rel_christ_other 2.vig_religion:1.res_rel_christ_other ///
2.res_rel_christ_other 3.res_rel_christ_other 3.vig_religion:1.res_rel_christ_other 2.res_rel_christ_other 3.res_rel_christ_other)   ///
coeflabels(1.res_rel_christ_other = `""Befragte(r)" "= Christ""' 2.res_rel_christ_other = `""Befragte(r) =" "Andere Religion""' ///
3.res_rel_christ_other = `""Befragte(r) =" "Keine Religion""' )   ///
eqlabels(`""Vignette" "= Christ""' `""Vignette" "= Moslem""') ///
title("Konditionale Effekte der Vignettenreligion", span) subtitle("Ref. Vignette = Keine Religion", span)
	
 
 
 * Additional statistical tests reported in the text of the paper
 est restore m9_l
 margins i.res_employment4#i.res_educ_cat, dydx(i.vig_qualific) post
 est store mar9_l_eco
	test _b[1.vig_qualific:1bn.res_employment4#1bn.res_educ_cat]=_b[1.vig_qualific:1bn.res_employment4#3.res_educ_cat] // full time low vs. high educ
	test _b[1.vig_qualific:4.res_employment4#1bn.res_educ_cat] = _b[1.vig_qualific:4.res_employment4#3.res_educ_cat]	// not in lab force low vs. high educ
	test  _b[1.vig_qualific:3.res_employment4#1bn.res_educ_cat] = _b[1.vig_qualific:3.res_employment4#3.res_educ_cat]	// unempl. low vs. high educ
	
 est restore m9_w
 margins i.res_employment4#i.res_educ_cat, dydx(i.vig_qualific) post
	test _b[1.vig_qualific:1bn.res_employment4#1bn.res_educ_cat]=_b[1.vig_qualific:1bn.res_employment4#3.res_educ_cat] // full time low vs. high educ
	test _b[1.vig_qualific:4.res_employment4#1bn.res_educ_cat] = _b[1.vig_qualific:4.res_employment4#3.res_educ_cat]	// not in lab force low vs. high educ
	test  _b[1.vig_qualific:3.res_employment4#1bn.res_educ_cat] = _b[1.vig_qualific:3.res_employment4#3.res_educ_cat]	// unempl. low vs. high educ
		
 est store mar9_w_eco
 est restore m9_b
 margins i.res_employment4#i.res_educ_cat, dydx(i.vig_qualific) post
 est store mar9_b_eco
 
 * Plotting the economic interactions - Abbildung 5
 coefplot (mar9_l_eco, label("Aufenthaltserlaubnis")) (mar9_w_eco, label("Arbeitserlaubnis"))  ///
 , scheme(s1mono) msymbol(circle) aspect(1)  scale(.75) xline(0)  ///
keep(1.res_employment4#1.res_educ_cat 1.res_employment4#3.res_educ_cat 3.res_employment4#1.res_educ_cat ///
3.res_employment4#3.res_educ_cat 4.res_employment4#1.res_educ_cat 4.res_employment4#3.res_educ_cat )   ///
coeflabels( ///
1.res_employment4#1.res_educ_cat = `""Befragte(r) =" "Vollzeit, geringe Bildung""' ///
1.res_employment4#3.res_educ_cat = `""Befragte(r) =" "Vollzeit, hohe Bildung""' ///
3.res_employment4#1.res_educ_cat = `""Befragte(r) =" "Arbeitslos, geringe Bildung""' ///
3.res_employment4#3.res_educ_cat = `""Befragte(r) =" "Arbeitslos, hohe Bildung""' ///
4.res_employment4#1.res_educ_cat = `""Befragte(r) =" "Nicht erwerbstätig, geringe Bildung""' ///
4.res_employment4#3.res_educ_cat = `""Befragte(r) =" "Nicht erwerbstätig, hohe Bildung""' )   ///
title("Konditionale Effekte: Vignettenqualifikation", span) subtitle("Effekt: Bildung = hoch (Ref. = gering)", span)



*********************************

log close
